import { Vue } from 'vue-property-decorator';
import { Item } from './types';
interface ContainerData {
    windowSize: ElementSize;
    windowScroll: ElementScroll;
    elementWindowOffset: number;
    elementSize: ElementSize;
}
interface ElementSize {
    width: number;
    height: number;
}
interface ElementScroll {
    x: number;
    y: number;
}
interface ConfigData<P> {
    windowMargin: number;
    gridGap: number;
    columnCount: number;
    entries: Item<P>[];
}
interface Cell<P> extends Item<P> {
    columnNumber: number;
    rowNumber: number;
    offset: number;
}
interface LayoutData<P> {
    totalHeight: number;
    cells: Cell<P>[];
}
interface RenderData<P> {
    cellsToRender: Cell<P>[];
    firstRenderedRowNumber: number | null;
    firstRenderedRowOffset: number | null;
}
export default class VirtualGrid<P> extends Vue {
    items: Item<P>[];
    updateFunction: () => Promise<boolean>;
    getGridGap: (elementWidth: number, windowHeight: number) => number;
    getColumnCount: (elementWidth: number) => number;
    getWindowMargin: (windowHeight: number) => number;
    getItemRatioHeight: (height: number, width: number, columnWidth: number) => number;
    updateTriggerMargin: number;
    loader: Vue.Component;
    debug: boolean;
    updateLock: boolean;
    bottomReached: boolean;
    ref: Element;
    containerData: ContainerData;
    get loadingBatch(): boolean;
    get configData(): ConfigData<P>;
    get layoutData(): LayoutData<P>;
    get renderData(): RenderData<P>;
    mounted(): void;
    beforeDestroy(): void;
    resize(): void;
    scroll(): void;
    initiliazeGrid(): void;
    loadMoreData(): void;
    loadMoreDataAsync(): Promise<void>;
    computeContainerData(): void;
    computeConfigData(containerData: ContainerData, items: Item<P>[]): ConfigData<P>;
    computeLayoutData(configData: ConfigData<P>): LayoutData<P>;
    computeRenderData(configData: ConfigData<P>, containerData: ContainerData, layoutData: LayoutData<P>): RenderData<P>;
    getColumnWidth(columnCount: number | null, gridGap: number | null, elementWidth: number | null): number;
    getGridRowStart(cell: Cell<P>, renderData: RenderData<P> | null): string;
    resetGrid(): void;
    isSameElementSize(a: ElementSize, b: ElementSize): boolean;
    getWindowSize(): ElementSize;
    getElementSize(element: Element): ElementSize;
    isSameElementScroll(a: ElementScroll, b: ElementScroll): boolean;
    getWindowScroll(): ElementScroll;
    getElementOffset(element: Element): number;
}
export {};
